==> dao.api-2.1.0-sources.jar: hbm/service/mapper/AbstractBusinessMapperService.java <==
package hbm.service.mapper;

import hbm.dao.jpa.EntityManagerDao;
import hbm.domain.BusinessObject;
import hbm.entity.BaseEntity;
import hbm.mapper.EntityBOMapper;

import java.io.Serializable;

import lombok.Getter;
import lombok.Setter;
import de.alpharogroup.lang.ObjectUtils;
import de.alpharogroup.lang.TypeArgumentsUtils;

public abstract class AbstractBusinessMapperService<
PK extends Serializable, 
BO extends BusinessObject<PK>, 
E extends BaseEntity<PK>, 
DAO extends EntityManagerDao<E, PK>,
M extends EntityBOMapper<E, BO>>
 implements
		BusinessMapperService<PK, BO> {
	/** The dao reference. */
	@Setter
	@Getter
	private DAO dao;
	@Setter
	@Getter
	private M mapper;
    /** The entity class. */
    @SuppressWarnings("unchecked")
    @Getter
    private final Class<E> entityClass = (Class<E>) TypeArgumentsUtils.getTypeArgument(AbstractBusinessMapperService.class, getClass(), 2);
    
    /** The bo class. */
    @SuppressWarnings("unchecked")
    @Getter
    private final Class<BO> businessObjectClass = (Class<BO>) TypeArgumentsUtils.getTypeArgument(AbstractBusinessMapperService.class, getClass(), 1);
    
	@Override
	public BO read(PK id) {
		E entity = dao.get(id);
		return getMapper().toBusinessObject(entity);
	}

	@Override
	public BO create(BO businessObject) {
		E entity = getMapper().toEntity(businessObject);
		businessObject.setId(dao.save(entity));
		return businessObject;
	}

	@Override
	public void update(BO businessObject) {
		E entity = dao.get(businessObject.getId());
		ObjectUtils.copyQuietly(entity, businessObject);
		dao.merge(entity);
	}

	@Override
	public void delete(PK id) {
		dao.delete(id);
	}
	

}

==> dao.api-2.2.0-sources.jar: hbm/service/mapper/AbstractBusinessMapperService.java <==
package hbm.service.mapper;

import hbm.dao.jpa.EntityManagerDao;
import hbm.domain.BusinessObject;
import hbm.entity.BaseEntity;
import hbm.mapper.EntityBOMapper;

import java.io.Serializable;

import lombok.Getter;
import lombok.Setter;
import de.alpharogroup.lang.ObjectExtensions;
import de.alpharogroup.lang.TypeArgumentsUtils;

public abstract class AbstractBusinessMapperService<
PK extends Serializable, 
BO extends BusinessObject<PK>, 
E extends BaseEntity<PK>, 
DAO extends EntityManagerDao<E, PK>,
M extends EntityBOMapper<E, BO>>
 implements
		BusinessMapperService<PK, BO> {
	/** The dao reference. */
	@Setter
	@Getter
	private DAO dao;
	@Setter
	@Getter
	private M mapper;
    /** The entity class. */
    @SuppressWarnings("unchecked")
    @Getter
    private final Class<E> entityClass = (Class<E>) TypeArgumentsUtils.getTypeArgument(AbstractBusinessMapperService.class, getClass(), 2);
    
    /** The bo class. */
    @SuppressWarnings("unchecked")
    @Getter
    private final Class<BO> businessObjectClass = (Class<BO>) TypeArgumentsUtils.getTypeArgument(AbstractBusinessMapperService.class, getClass(), 1);
    
	@Override
	public BO read(PK id) {
		E entity = dao.get(id);
		return getMapper().toBusinessObject(entity);
	}

	@Override
	public BO create(BO businessObject) {
		E entity = getMapper().toEntity(businessObject);
		businessObject.setId(dao.save(entity));
		return businessObject;
	}

	@Override
	public void update(BO businessObject) {
		E entity = dao.get(businessObject.getId());
		ObjectExtensions.copyQuietly(entity, businessObject);
		dao.merge(entity);
	}

	@Override
	public void delete(PK id) {
		dao.delete(id);
	}
	

}
